@@ -77,7 +77,16 @@ DBusRunner::DBusRunner(QObject *parent, const KPluginMetaData &data)
         m_matchingServices << requestedServiceName;
     }
 
-    connect(this, &AbstractRunner::teardown, this, &DBusRunner::teardown);
+    connect(this, &AbstractRunner::teardown, this, [this]() {
+        if (m_matchWasCalled) {
+            for (const QString &service : std::as_const(m_matchingServices)) {
+                auto method = QDBusMessage::createMethodCall(service, m_path, m_ifaceName, QStringLiteral("Teardown"));
+                QDBusConnection::sessionBus().asyncCall(method);
+            }
+        }
+        m_actionsForSessionRequested = false;
+        m_matchWasCalled = false;
+    });
 
     // Load the runner syntaxes
     const QStringList syntaxes = data.value(QStringLiteral("X-Plasma-Runner-Syntaxes"), QStringList());
@@ -99,18 +108,6 @@ void DBusRunner::reloadConfiguration()
     }
 }
 
-void DBusRunner::teardown()
-{
-    if (m_matchWasCalled) {
-        for (const QString &service : std::as_const(m_matchingServices)) {
-            auto method = QDBusMessage::createMethodCall(service, m_path, m_ifaceName, QStringLiteral("Teardown"));
-            QDBusConnection::sessionBus().asyncCall(method);
-        }
-    }
-    m_actionsForSessionRequested = false;
-    m_matchWasCalled = false;
-}
-
 void DBusRunner::requestActionsForService(const QString &service, const std::function<void()> &finishedCallback)
 {
     if (m_actionsForSessionRequested) {
@@ -252,9 +249,9 @@ void DBusRunner::matchInternal(KRunner::RunnerContext context)
                 pendingServices->erase(service);
                 if (reply.isError()) {
                     qCWarning(KRUNNER) << "Error requesting matches; calling" << service << " :" << reply.error().name() << reply.error().message();
-                    return;
+                } else {
+                    context.addMatches(convertMatches(service, reply.value()));
                 }
-                context.addMatches(convertMatches(service, reply.value()));
                 // We are finished when all watchers finished
                 if (pendingServices->size() == 0) {
                     Q_EMIT matchInternalFinished(jobId);
